pathmaker

package
v0.11.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2023 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package pathmaker defines utility functions used to navigate through the project structure.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type SveltinPathMaker

type SveltinPathMaker struct {
	// contains filtered or unexported fields
}

SveltinPathMaker is the main struct to deal with path within a Sveltin/SvelteKit project structure.

func NewSveltinPathMaker

func NewSveltinPathMaker(settings *config.SveltinSettings) *SveltinPathMaker

NewSveltinPathMaker returns a SveltinPathMaker struct.

func (*SveltinPathMaker) GetAPIFolder

func (maker *SveltinPathMaker) GetAPIFolder() string

GetAPIFolder returns a string representing the path to the 'src/routes/api' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetConfigFolder

func (maker *SveltinPathMaker) GetConfigFolder() string

GetConfigFolder returns a string representing the path to the 'config' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetContentFolder

func (maker *SveltinPathMaker) GetContentFolder() string

GetContentFolder returns a string representing the path to the 'content' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetLibFolder

func (maker *SveltinPathMaker) GetLibFolder() string

GetLibFolder returns a string representing the path to the 'src/lib' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetParamsFolder

func (maker *SveltinPathMaker) GetParamsFolder() string

GetParamsFolder returns a string representing the path to the 'src/params' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetPathToExistingResources

func (maker *SveltinPathMaker) GetPathToExistingResources() string

GetPathToExistingResources returns a string representing the path to the 'content' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetPathToPublicPages

func (maker *SveltinPathMaker) GetPathToPublicPages() string

GetPathToPublicPages returns a string representing the path to the 'src/routes' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetPathToRoutes

func (maker *SveltinPathMaker) GetPathToRoutes() string

GetPathToRoutes returns a string representing the path to the 'src/routes' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetProjectConfigFolder

func (maker *SveltinPathMaker) GetProjectConfigFolder(project string) string

GetProjectConfigFolder returns a string representing the path to the 'config' folder for a sveltin project relative to the current working directory.

func (*SveltinPathMaker) GetProjectContentFolder

func (maker *SveltinPathMaker) GetProjectContentFolder(project string) string

GetProjectContentFolder returns a string representing the path to the 'content' folder for a sveltin project relative to the current working directory.

func (*SveltinPathMaker) GetProjectRoot

func (maker *SveltinPathMaker) GetProjectRoot(project string) string

GetProjectRoot returns a string representing the path to the sveltin project folder relative to the current working directory.

func (*SveltinPathMaker) GetProjectThemesFolder

func (maker *SveltinPathMaker) GetProjectThemesFolder(project string) string

GetProjectThemesFolder returns a string representing the path to the 'themes' folder for a sveltin project relative to the current working directory.

func (*SveltinPathMaker) GetResourceContentFilename

func (maker *SveltinPathMaker) GetResourceContentFilename() string

GetResourceContentFilename returns a string representing the filename for a resource content page.

func (*SveltinPathMaker) GetResourceLibFilename

func (maker *SveltinPathMaker) GetResourceLibFilename(artifact string) string

GetResourceLibFilename returns a string representing the path to the resource lib file for a sveltin project relative to the current working directory.

func (*SveltinPathMaker) GetRootFolder

func (maker *SveltinPathMaker) GetRootFolder() string

GetRootFolder returns a string representing the path to the project root folder.

func (*SveltinPathMaker) GetRoutesFolder

func (maker *SveltinPathMaker) GetRoutesFolder() string

GetRoutesFolder returns a string representing the path to the 'src/routes' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetSrcFolder added in v0.11.0

func (maker *SveltinPathMaker) GetSrcFolder() string

GetSrcFolder returns a string representing the path to the 'src' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetStaticFolder

func (maker *SveltinPathMaker) GetStaticFolder() string

GetStaticFolder returns a string representing the path to the 'static' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetThemeComponentsFolder

func (maker *SveltinPathMaker) GetThemeComponentsFolder() string

GetThemeComponentsFolder returns a string representing the path to the 'themes/<theme>/components' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetThemePartialsFolder

func (maker *SveltinPathMaker) GetThemePartialsFolder() string

GetThemePartialsFolder returns a string representing the path to the 'themes/<theme>/partials' folder for a sveltin project relative to the project root folder.

func (*SveltinPathMaker) GetThemesFolder

func (maker *SveltinPathMaker) GetThemesFolder() string

GetThemesFolder returns a string representing the path to the 'themes' folder for a sveltin project relative to the project root folder.

Jump to